@@ -1,5 +1,5 @@
 package POEx::IRC::Backend;
-$POEx::IRC::Backend::VERSION = '0.030001';
+$POEx::IRC::Backend::VERSION = '0.030002';
 use strictures 2;
 
 use Carp;
@@ -693,14 +693,14 @@ sub _disconnected {
   $poe_kernel->alarm_remove( $this_conn->alarm_id ) 
     if $this_conn->has_alarm_id;
 
+  ## Already a dead Connect (wheel was cleared), nothing to do
+  return unless $this_conn->has_wheel;
+
   if (RUNNING_IN_HELL) {
     $this_conn->wheel->shutdown_input;
     $this_conn->wheel->shutdown_output;
   }
 
-  ## Higher layers may still have a $conn object bouncing about.
-  ## They should check ->has_wheel to determine if the Connect obj
-  ## has been disconnected (no longer has a wheel).
   $this_conn->clear_wheel;
 
   $poe_kernel->post( $self->controller => 
@@ -774,8 +774,6 @@ sub unset_compressed_link {
   $self
 }
 
-## FIXME listener connect ip blacklist?
-
 no warnings 'void';
 print
  qq[<CaptObviousman> pretend for a moment that I'm stuck with mysql\n],
@@ -1129,8 +1127,7 @@ These events are dispatched to the controller session; see L</register>.
 
 Dispatched when a connection wheel has had a compression filter added.
 
-C<$_[ARG0]> is the connection's 
-L<POEx::IRC::Backend::Connect>
+C<$_[ARG0]> is the connection's L<POEx::IRC::Backend::Connect>.
 
 =head3 ircsock_connection_idle
 
@@ -1138,10 +1135,11 @@ Dispatched when a connection wheel has had no input for longer than
 specified idle time (see L</create_listener> regarding idle times).
 
 Currently these events are only issued for incoming Connects accepted on a
-Listener, not outgoing Connects created by a Connector.
+Listener, not outgoing Connects created by a Connector; if you need to do
+ping/pong-style heartbeating on an outgoing Connector-spawned socket, you will
+need to run your own timer.
 
-C<$_[ARG0]> is the connection's 
-L<POEx::IRC::Backend::Connect>
+C<$_[ARG0]> is the connection's L<POEx::IRC::Backend::Connect>.
 
 See also: L<POEx::IRC::Backend::Connect/ping_pending>
 
