@@ -1,10 +1,11 @@
 package POEx::IRC::Backend::Role::HasWheel;
-$POEx::IRC::Backend::Role::HasWheel::VERSION = '0.030001';
+$POEx::IRC::Backend::Role::HasWheel::VERSION = '0.030002';
 use Types::Standard -all;
 
 use Moo::Role;
 
 has wheel_id => (
+  # lazy but set by trigger in ->wheel:
   lazy    => 1,
   isa     => Defined,
   is      => 'ro',
@@ -35,25 +36,23 @@ has wheel => (
 
 POEx::IRC::Backend::Role::HasWheel
 
-=head1 SYNOPSIS
-
-A L<Moo::Role> for classes that have associated POE::Wheel instances.
-
 =head1 DESCRIPTION
 
 =head2 wheel
 
-A L<POE::Wheel> instance (typically L<POE::Wheel::SocketFactory> for listeners
-and connectors or L<POE::Wheel::ReadWrite> for live connections).
+A L<POE::Wheel> instance; typically L<POE::Wheel::SocketFactory> for
+L<POEx::IRC::Backend::Listener> and L<POEx::IRC::Backend::Connector> objects,
+or L<POE::Wheel::ReadWrite> for live L<POEx::IRC::Backend::Connect> objects.
 
-This is primarily for internal use. External code should not interact directly
-with the C<wheel>.
+This is primarily for internal use. B<< External code should not interact
+directly with the C<wheel>; >> doing so may result in misdelivered events and
+other unexpected behavior.
 
-Can be cleared via B<clear_wheel>; use B<has_wheel> to determine if this
-listener's wheel has been cleared.
+Clearer: B<clear_wheel>
 
-Can be replaced via B<set_wheel> (although whether this is a good idea or not
-is debatable; better to spawn a new instance of your class)
+Predicate: B<has_wheel>
+
+Writer: B<set_wheel>
 
 =head2 wheel_id
 
